import IHTMLMetaElement from './IHTMLMetaElement';
import HTMLElement from '../html-element/HTMLElement';

/**
 * HTML Meta Element.
 *
 * Reference:
 * https://developer.mozilla.org/en-US/docs/Web/API/HTMLMetaElement.
 */
export default class HTMLMetaElement extends HTMLElement implements IHTMLMetaElement {
	/**
	 * Returns content.
	 *
	 * @returns Content.
	 */
	public get content(): string {
		return this.getAttributeNS(null, 'content') || '';
	}

	/**
	 * Sets content.
	 *
	 * @param content Content.
	 */
	public set content(content: string) {
		this.setAttributeNS(null, 'content', content);
	}

	/**
	 * Returns httpEquiv.
	 *
	 * @returns HttpEquiv.
	 */
	public get httpEquiv(): string {
		return this.getAttributeNS(null, 'http-equiv') || '';
	}

	/**
	 * Sets httpEquiv.
	 *
	 * @param httpEquiv HttpEquiv.
	 */
	public set httpEquiv(httpEquiv: string) {
		this.setAttributeNS(null, 'http-equiv', httpEquiv);
	}

	/**
	 * Returns name.
	 *
	 * @returns Name.
	 */
	public get name(): string {
		return this.getAttributeNS(null, 'name') || '';
	}

	/**
	 * Sets name.
	 *
	 * @param name Name.
	 */
	public set name(name: string) {
		this.setAttributeNS(null, 'name', name);
	}
	/**
	 * Returns scheme.
	 *
	 * @returns Name.
	 */
	public get scheme(): string {
		return this.getAttributeNS(null, 'scheme') || '';
	}

	/**
	 * Sets scheme.
	 *
	 * @param scheme Scheme.
	 */
	public set scheme(scheme: string) {
		this.setAttributeNS(null, 'scheme', scheme);
	}
}
